@@ -19,3 +19,8 @@ from .announcement_handling import get_index_announcement_data_from_db
 
 from .name_handling import post_index_name_acronyms_to_database
 from .name_handling import get_index_name_acronyms_from_database
+
+from .tracking_assumptions import post_tracking_assumptions_to_database
+from .tracking_assumptions import get_all_tracking_assumptions
+from .tracking_assumptions import get_index_tracking_assumption_history
+from .tracking_assumptions import get_most_recent_index_tracking_assumption
