@@ -34,7 +34,7 @@ def post_announcements_to_database(dataset: pd.DataFrame, access_token: str, ver
                 print("Status Code: {}, user not authenticated for endpoint.".format(response.status_code))
         else:
             if verbose:
-                print("Status Code: {}, please contact support.".format(response.status_code))
+                print("Status Code: {}, {}.".format(response.status_code, response.text))
 
 
 def get_all_index_announcements_from_db(index: str, access_token: str, verbose: bool = True):
@@ -70,7 +70,7 @@ def get_all_index_announcements_from_db(index: str, access_token: str, verbose:
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
 
@@ -109,7 +109,7 @@ def get_multiple_index_announcement_data_from_db(index: str, review_type: str, a
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
 
@@ -158,5 +158,5 @@ def get_index_announcement_data_from_db(index: str, review_year: int, review_mon
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
