@@ -28,12 +28,12 @@ def post_dates_to_database(dataset: pd.DataFrame, access_token: str, verbose: bo
         if response.status_code in [200, 201, 202, 203, 204]:
             if verbose:
                 print("Status Code: {}, data posted to date table.".format(response.status_code))
-        elif response.status_code == 401:
+        elif response.status_code in [401, 403]:
             if verbose:
                 print("Status Code: {}, user not authenticated for endpoint.".format(response.status_code))
         else:
             if verbose:
-                print("Status Code: {}, please contact support.".format(response.status_code))
+                print("Status Code: {}, {}.".format(response.status_code, response.text))
 
 
 def get_all_index_dates_from_db(index: str, access_token: str, verbose: bool = True):
@@ -61,15 +61,16 @@ def get_all_index_dates_from_db(index: str, access_token: str, verbose: bool = T
         return pd.read_json(response.text)
     elif response.status_code == 404:
         if verbose:
-            print("Status Code: {}, cannot find Announcement data for this Index.".format(response.status_code))
+            print("Status Code: {}, cannot find Announcement data for {}.".format(response.status_code,
+                                                                                  index))
         return pd.DataFrame()
-    elif response.status_code == 401:
+    elif response.status_code in [401, 403]:
         if verbose:
             print("Status Code: {}, user not properly authenticated for endpoint.".format(response.status_code))
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
 
@@ -103,14 +104,14 @@ def get_index_dates_data_from_db(index: str, review_year: int, review_month: int
     if response.status_code == 200:
         if verbose:
             print("Status Code: {}".format(response.status_code))
-        return pd.read_json(response.text)
+        return pd.json_normalize(json.loads(response.text))
     elif response.status_code == 404:
         if verbose:
-            print("Status Code: {}, no Announcement data available for the {}{}{} review".format(response.status_code,
-                                                                                                 index,
-                                                                                                 review_year,
-                                                                                                 review_month,
-                                                                                                 review_type))
+            print("Status Code: {}, no Announcement data available for the {}-{}-{} review".format(response.status_code,
+                                                                                                   index,
+                                                                                                   review_year,
+                                                                                                   review_month,
+                                                                                                   review_type))
         return pd.DataFrame()
     elif response.status_code == 401:
         if verbose:
@@ -118,5 +119,6 @@ def get_index_dates_data_from_db(index: str, review_year: int, review_month: int
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
+
