@@ -26,12 +26,12 @@ def post_flows_to_database(dataset: pd.DataFrame, access_token: str, verbose: bo
     header = {'Authorization': 'Bearer ' + access_token}
     for item in dict_list:
         response = requests.post(url, data=json.dumps(item), headers=header)
-        if response.status_code == 200:
+        if response.status_code in [200, 201]:
             if verbose:
                 print("Status Code: {}, Uploaded.".format(response.status_code))
         else:
             if verbose:
-                print("Status Code: {}, Failed to Upload.".format(response.status_code))
+                print("Status Code: {}, {}.".format(response.status_code, response.text))
 
 
 def get_all_index_data_from_db(index: str, access_token: str, verbose: bool = True):
@@ -67,7 +67,7 @@ def get_all_index_data_from_db(index: str, access_token: str, verbose: bool = Tr
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
 
@@ -116,7 +116,7 @@ def get_index_review_data_from_db(index: str, review_year: int, review_month: in
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
 
@@ -164,7 +164,7 @@ def get_index_review_data_single_day(index: str, review_year: int, review_month:
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
 
@@ -216,5 +216,5 @@ def get_index_review_data_daterange(index: str, review_year: int, review_month:
         return pd.DataFrame()
     else:
         if verbose:
-            print("Status Code: {}, please contact support.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
